@@ -100,10 +100,11 @@ DEFAULT_CONFIG = {
         'telegram': {
             'enabled': False,
             'bot_token': '',
-            'chat-id': '',
+            'chat_id': '',
         },
         'mailgun': {
             'enabled': False,
+            'region': 'us',
             'api_key': '',
             'domain': '',
             'from_mail': '',
